summaryrefslogtreecommitdiffstats
path: root/macosx/Controller.m
diff options
context:
space:
mode:
authordynaflash <[email protected]>2012-02-19 22:14:57 +0000
committerdynaflash <[email protected]>2012-02-19 22:14:57 +0000
commitdbdaabaa73fa1a371aeba3ecd802bb5e003e08bf (patch)
treef3b23a15c223e4836d8c93f897a247c59da7b8da /macosx/Controller.m
parent68395c181bbf629c33607829aa971cf12c19c29d (diff)
MacGui: Fix an issue where lavc options were shown and passed when Theora was chosen.
git-svn-id: svn://svn.handbrake.fr/HandBrake/trunk@4457 b64f7644-9d1e-0410-96f1-a4d463321fa5
Diffstat (limited to 'macosx/Controller.m')
-rw-r--r--macosx/Controller.m14
1 files changed, 12 insertions, 2 deletions
diff --git a/macosx/Controller.m b/macosx/Controller.m
index 7a1aa1c58..0a6322bbd 100644
--- a/macosx/Controller.m
+++ b/macosx/Controller.m
@@ -4803,9 +4803,19 @@ the user is using "Custom" settings by determining the sender*/
[fAdvancedOptions setHidden:NO];
[self autoSetM4vExtension: sender];
}
- else // we are FFmpeg (lavc)
+ else // we are FFmpeg (lavc) or Theora
{
- [fAdvancedOptions setHidden:YES];
+ [fAdvancedOptions setHidden:YES];
+
+ // We Are Lavc
+ if ([[fVidEncoderPopUp selectedItem] tag] & HB_VCODEC_FFMPEG_MASK )
+ {
+ [fAdvancedOptions setLavcOptsEnabled:YES];
+ }
+ else /// We are Theora
+ {
+ [fAdvancedOptions setLavcOptsEnabled:NO];
+ }
}